@@ -30,6 +30,7 @@ from graph_notebook.configuration.generate_config import generate_default_config
     AuthModeEnum, Configuration
 from graph_notebook.decorators.decorators import display_exceptions, magic_variables
 from graph_notebook.magics.ml import neptune_ml_magic_handler, generate_neptune_ml_parser
+from graph_notebook.magics.streams import StreamViewer
 from graph_notebook.neptune.client import ClientBuilder, Client, VALID_FORMATS, PARALLELISM_OPTIONS, PARALLELISM_HIGH, \
     LOAD_JOB_MODES, MODE_AUTO, FINAL_LOAD_STATUSES, SPARQL_ACTION, FORMAT_CSV
 from graph_notebook.network import SPARQLNetwork
@@ -195,7 +196,25 @@ class Graph(Magics):
             print(json.dumps(config_dict, indent=2))
 
         return self.graph_notebook_config
+    
 
+    @line_magic
+    def stream_viewer(self,line):
+        parser = argparse.ArgumentParser()
+        parser.add_argument('language', type=str.lower, nargs='?', default='gremlin',
+                            help='language  (default=gremlin) [gremlin|sparql]',
+                            choices = ['gremlin','sparql'])
+
+        parser.add_argument('--limit', type=int, default=10, help='Maximum number of rows to display at a time')
+
+        args = parser.parse_args(line.split())
+        
+        language = args.language
+        limit = args.limit
+        uri = self.client.get_uri_with_port()
+        viewer = StreamViewer(self.client,uri,language,limit=limit)
+        viewer.show()
+        
     @line_magic
     def graph_notebook_host(self, line):
         if line == '':
@@ -225,6 +244,10 @@ class Graph(Magics):
         parser.add_argument('--explain-format', default='text/html', help='response format for explain query mode',
                             choices=['text/csv', 'text/html'])
         parser.add_argument('--store-to', type=str, default='', help='store query result to this variable')
+        parser.add_argument('-sp', '--stop-physics', action='store_true', default=False,
+                            help="Disable visualization physics after the initial simulation stabilizes.")
+        parser.add_argument('-sd', '--simulation-duration', type=int, default=1500,
+                            help='Specifies maximum duration of visualization physics simulation. Default is 1500ms')
         args = parser.parse_args(line.split())
         mode = str_to_query_mode(args.query_mode)
         tab = widgets.Tab()
@@ -280,6 +303,9 @@ class Graph(Magics):
 
                 logger.debug(f'number of nodes is {len(sn.graph.nodes)}')
                 if len(sn.graph.nodes) > 0:
+                    self.graph_notebook_vis_options['physics']['disablePhysicsAfterInitialSimulation'] \
+                        = args.stop_physics
+                    self.graph_notebook_vis_options['physics']['simulationDuration'] = args.simulation_duration
                     f = Force(network=sn, options=self.graph_notebook_vis_options)
                     titles.append('Graph')
                     children.append(f)
@@ -394,6 +420,11 @@ class Graph(Magics):
                                  'TinkerPop driver "Serializers" enum values. Default is application/json')
         parser.add_argument('--indexOps', action='store_true', default=False,
                             help='Show a detailed report of all index operations.')
+        parser.add_argument('-sp', '--stop-physics', action='store_true', default=False,
+                            help="Disable visualization physics after the initial simulation stabilizes.")
+        parser.add_argument('-sd', '--simulation-duration', type=int, default=1500,
+                            help='Specifies maximum duration of visualization physics simulation. Default is 1500ms')
+
         args = parser.parse_args(line.split())
         mode = str_to_query_mode(args.query_mode)
         logger.debug(f'Arguments {args}')
@@ -461,6 +492,9 @@ class Graph(Magics):
                     gn.add_results_with_pattern(query_res, pattern)
                 logger.debug(f'number of nodes is {len(gn.graph.nodes)}')
                 if len(gn.graph.nodes) > 0:
+                    self.graph_notebook_vis_options['physics']['disablePhysicsAfterInitialSimulation'] \
+                        = args.stop_physics
+                    self.graph_notebook_vis_options['physics']['simulationDuration'] = args.simulation_duration
                     f = Force(network=gn, options=self.graph_notebook_vis_options)
                     titles.append('Graph')
                     children.append(f)
@@ -1317,7 +1351,6 @@ class Graph(Magics):
     def graph_notebook_version(self, line):
         print(graph_notebook.__version__)
 
-    # TODO: find out where we call this, then add local_ns param and variable decorator
     @line_cell_magic
     @display_exceptions
     def graph_notebook_vis_options(self, line='', cell=''):
@@ -1363,12 +1396,16 @@ class Graph(Magics):
                             help='Specifies max length of vertex label, in characters. Default is 10')
         parser.add_argument('--store-to', type=str, default='', help='store query result to this variable')
         parser.add_argument('--ignore-groups', action='store_true', default=False, help="Ignore all grouping options")
+        parser.add_argument('-sp', '--stop-physics', action='store_true', default=False,
+                            help="Disable visualization physics after the initial simulation stabilizes.")
+        parser.add_argument('-sd', '--simulation-duration', type=int, default=1500,
+                            help='Specifies maximum duration of visualization physics simulation. Default is 1500ms')
         args = parser.parse_args(line.split())
         tab = widgets.Tab()
         logger.debug(args)
         titles = []
         children = []
-        force_graph_output=None
+        force_graph_output = None
         res = None
         if args.mode == 'query':
             query_start = time.time() * 1000  # time.time() returns time in seconds w/high precision; x1000 to get in ms
@@ -1377,7 +1414,7 @@ class Graph(Magics):
             oc_http.raise_for_status()
             res = oc_http.json()
             oc_metadata = build_opencypher_metadata_from_query(query_type='query', results=res,
-                                                               query_time=query_time)            
+                                                               query_time=query_time)
             try:
                 gn = OCNetwork(group_by_property=args.group_by, display_property=args.display_property,
                                edge_display_property=args.edge_display_property,
@@ -1385,9 +1422,13 @@ class Graph(Magics):
                 gn.add_results(res)
                 logger.debug(f'number of nodes is {len(gn.graph.nodes)}')
                 if len(gn.graph.nodes) > 0:
+                    self.graph_notebook_vis_options['physics']['disablePhysicsAfterInitialSimulation'] \
+                        = args.stop_physics
+                    self.graph_notebook_vis_options['physics']['simulationDuration'] = args.simulation_duration
                     force_graph_output = Force(network=gn, options=self.graph_notebook_vis_options)
-            except ValueError as value_error:
-                logger.debug(f'unable to create network from result. Skipping from result set: {value_error}')
+            except (TypeError, ValueError) as network_creation_error:
+                logger.debug(f'Unable to create network from result. Skipping from result set: {res}')
+                logger.debug(f'Error: {network_creation_error}')
         elif args.mode == 'bolt':
             res = self.client.opencyper_bolt(cell)            
             # Need to eventually add code to parse and display a network for the bolt format here
