@@ -68,6 +68,12 @@ EXPORT_ACTION = 'neptune-export'
 EXTRA_HEADERS = {'content-type': 'application/json'}
 SPARQL_ACTION = 'sparql'
 
+STREAM_AT = 'AT_SEQUENCE_NUMBER'
+STREAM_AFTER = 'AFTER_SEQUENCE_NUMBER'
+STREAM_TRIM = 'TRIM_HORIZON'
+STREAM_EXCEPTION_NOT_FOUND = 'StreamRecordsNotFoundException'
+STREAM_EXCEPTION_NOT_ENABLED = 'UnsupportedOperationException'
+
 
 class Client(object):
     def __init__(self, host: str, port: int = DEFAULT_PORT, ssl: bool = True, region: str = DEFAULT_REGION,
@@ -85,6 +91,10 @@ class Client(object):
 
         self._http_session = None
 
+    def get_uri_with_port(self):
+        uri = f'{self._http_protocol}://{self.host}:{self.port}'
+        return uri
+
     def sparql_query(self, query: str, headers=None, explain: str = '', path: str = '') -> requests.Response:
         if headers is None:
             headers = {}
@@ -177,6 +187,7 @@ class Client(object):
         res = self._http_session.send(req)
         return res
 
+
     def gremlin_status(self, query_id: str = '', include_waiting: bool = False):
         kwargs = {}
         if include_waiting:
@@ -256,6 +267,14 @@ class Client(object):
         driver = GraphDatabase.driver(url, auth=(user, password), encrypted=self.ssl)
         return driver
 
+    def stream(self, url, **kwargs) -> requests.Response: 
+        params = {}
+        for k, v in kwargs.items():
+            params[k] = v
+        req = self._prepare_request('GET', url, params=params,data='')
+        res = self._http_session.send(req)
+        return res.json()
+
     def status(self) -> requests.Response:
         url = f'{self._http_protocol}://{self.host}:{self.port}/status'
         req = self._prepare_request('GET', url, data='')
@@ -575,7 +594,15 @@ class Client(object):
         req = AWSRequest(method=method, url=url, data=data, params=params, headers=headers)
         if self.iam_enabled:
             credentials = self._session.get_credentials()
-            frozen_creds = credentials.get_frozen_credentials()
+            try:
+                frozen_creds = credentials.get_frozen_credentials()
+            except AttributeError:
+                print("Could not find valid IAM credentials in any the following locations:\n")
+                print("env, assume-role, assume-role-with-web-identity, sso, shared-credential-file, custom-process, "
+                      "config-file, ec2-credentials-file, boto-config, container-role, iam-role\n")
+                print("Go to https://boto3.amazonaws.com/v1/documentation/api/latest/guide/credentials.html for more "
+                      "details on configuring your IAM credentials.")
+                return req
             SigV4Auth(frozen_creds, service, self.region).add_auth(req)
             prepared_iam_req = req.prepare()
             return prepared_iam_req
